@@ -6,6 +6,7 @@ __docformat__ = 'restructuredtext en'
 
 from calibre.gui2.convert.pdb_output_ui import Ui_Form
 from calibre.gui2.convert import Widget
+from calibre.ebooks.conversion.config import OPTIONS
 
 format_model = None
 
@@ -18,7 +19,7 @@ class PluginWidget(Widget, Ui_Form):
     ICON = I('mimetypes/unknown.png')
 
     def __init__(self, parent, get_option, get_help, db=None, book_id=None):
-        Widget.__init__(self, parent, ['format', 'inline_toc', 'pdb_output_encoding'])
+        Widget.__init__(self, parent, OPTIONS['output']['pdb'])
         self.db, self.book_id = db, book_id
 
         for x in get_option('format').option.choices:
